#ifndef FILETRANSDLG_H
#define FILETRANSDLG_H

#include"ui_filetrans.h"
#include"im.h"
#include"s5b.h"

class PsiAccount;
namespace XMPP
{
	class FileTransfer;
}
using namespace XMPP;

class FileTransferHandler : public QObject
{
	Q_OBJECT
public:
	enum { ErrReject, ErrTransfer, ErrFile };
	FileTransferHandler(PsiAccount *pa, FileTransfer *ft=0);
	~FileTransferHandler();

	Jid peer() const;
	QString fileName() const;
	Q_LLONG fileSize() const;
	int totalSteps() const;

	void send(const Jid &to, const QString &fname);
	void accept(const QString &fname);

signals:
	void accepted();
	void statusMessage(const QString &s);
	void progress(int p, Q_LLONG sent);
	void error(int, const QString &s);

private slots:
	// s5b status
	void s5b_proxyQuery();
	void s5b_proxyResult(bool b);
	void s5b_requesting();
	void s5b_accepted();
	void s5b_tryingHosts(const StreamHostList &hosts);
	void s5b_proxyConnect();
	void s5b_waitingForActivation();

	// ft
	void ft_accepted();
	void ft_connected();
	void ft_readyRead(const QByteArray &);
	void ft_bytesWritten(int);
	void ft_error(int);
	void trySend();

private:
	class Private;
	Private *d;

	void mapSignals();
};

class FileTransDlg : public FileTransUI
{
	Q_OBJECT
public:
	FileTransDlg(const Jid &j, PsiAccount *pa);
	FileTransDlg(FileTransfer *ft, PsiAccount *pa);
	~FileTransDlg();

public slots:
	void done(int r);

private slots:
	void chooseFile();
	void doStart();
	void ft_accepted();
	void ft_statusMessage(const QString &s);
	void ft_progress(int p, Q_LLONG sent);
	void ft_error(int, const QString &);

private:
	class Private;
	Private *d;
};

#endif

